pub enum TempoPoolTransactionError {
Show 34 variants
ExceedsNonPaymentLimit,
InvalidFeeToken(Address),
PausedFeeToken(Address),
MissingFeeToken,
InvalidValidBefore {
valid_before: u64,
min_allowed: u64,
},
InvalidValidAfter {
valid_after: u64,
max_allowed: u64,
},
FeeCapBelowMinBaseFee {
max_fee_per_gas: u128,
min_base_fee: u64,
},
Keychain(&'static str),
InvalidFeePayerSignature,
SelfSponsoredFeePayer,
NonZeroValue,
SubblockNonceKey,
BlackListedFeePayer {
fee_token: Address,
fee_payer: Address,
},
InsufficientLiquidity(Address),
InsufficientGasForAAIntrinsicCost {
gas_limit: u64,
intrinsic_gas: u64,
},
TooManyAuthorizations {
count: usize,
max_allowed: usize,
},
TooManyCalls {
count: usize,
max_allowed: usize,
},
NoCalls,
CreateCallNotFirst,
CreateCallWithAuthorizationList,
CallInputTooLarge {
call_index: usize,
size: usize,
max_allowed: usize,
},
TooManyAccessListAccounts {
count: usize,
max_allowed: usize,
},
TooManyStorageKeysPerAccount {
account_index: usize,
count: usize,
max_allowed: usize,
},
TooManyTotalStorageKeys {
count: usize,
max_allowed: usize,
},
TooManyTokenLimits {
count: usize,
max_allowed: usize,
},
ExpiringNonceValidBeforeTooFar {
valid_before: u64,
max_allowed: u64,
},
ExpiringNonceReplay,
ExpiringNonceMissingValidBefore,
ExpiringNonceNonceNotZero,
AccessKeyExpired {
expiry: u64,
min_allowed: u64,
},
KeyAuthorizationExpired {
expiry: u64,
min_allowed: u64,
},
SpendingLimitExceeded {
fee_token: Address,
cost: U256,
remaining: U256,
},
LegacyKeychainPostT1C,
V2KeychainPreT1C,
}Variants
ExceedsNonPaymentLimit
InvalidFeeToken(Address)
PausedFeeToken(Address)
MissingFeeToken
InvalidValidBefore
InvalidValidAfter
FeeCapBelowMinBaseFee
Keychain(&'static str)
InvalidFeePayerSignature
SelfSponsoredFeePayer
NonZeroValue
SubblockNonceKey
Thrown if a Tempo Transaction with a nonce key prefixed with the sub-block prefix marker added to the pool
BlackListedFeePayer
Thrown if the fee payer of a transaction cannot transfer (is blacklisted) the fee token, thus making the payment impossible.
InsufficientLiquidity(Address)
Thrown when we couldn’t find a recently used validator token that has enough liquidity in fee AMM pair with the user token this transaction will pay fees in.
InsufficientGasForAAIntrinsicCost
Thrown when an AA transaction’s gas limit is insufficient for the calculated intrinsic gas. This includes per-call costs, signature verification, and other AA-specific gas costs.
TooManyAuthorizations
Thrown when an AA transaction has too many authorizations in its authorization list.
TooManyCalls
Thrown when an AA transaction has too many calls.
NoCalls
Thrown when an AA transaction has no calls.
CreateCallNotFirst
Thrown when a call in an AA transaction is the second call and is a CREATE.
CreateCallWithAuthorizationList
Thrown when an AA transaction contains both a CREATE call and an authorization list.
CallInputTooLarge
Thrown when a call in an AA transaction has input data exceeding the maximum allowed size.
TooManyAccessListAccounts
Thrown when an AA transaction has too many accounts in its access list.
TooManyStorageKeysPerAccount
Thrown when an access list entry has too many storage keys.
TooManyTotalStorageKeys
Thrown when the total number of storage keys across all access list entries is too large.
TooManyTokenLimits
Thrown when a key authorization has too many token limits.
ExpiringNonceValidBeforeTooFar
Thrown when an expiring nonce transaction’s valid_before is too far in the future.
ExpiringNonceReplay
Thrown when an expiring nonce transaction’s hash has already been seen (replay).
ExpiringNonceMissingValidBefore
Thrown when an expiring nonce transaction is missing the required valid_before field.
ExpiringNonceNonceNotZero
Thrown when an expiring nonce transaction has a non-zero nonce.
AccessKeyExpired
Thrown when an access key has expired or is expiring within the propagation buffer.
KeyAuthorizationExpired
Thrown when a KeyAuthorization has expired or is expiring within the propagation buffer.
SpendingLimitExceeded
Thrown when a keychain transaction’s fee token cost exceeds the spending limit.
LegacyKeychainPostT1C
Legacy V1 keychain signature rejected post-T1C (permanently invalid).
V2KeychainPreT1C
V2 keychain signature rejected pre-T1C (not yet valid).